@@ -108,7 +108,7 @@ public:
    * Revision history
    - SLKP 20170517 porting from v3 branch
    */
-  virtual void Initialize(bool = false);
+  virtual void Initialize(bool = true);
 
   /**
    * Clear the string (delete allocated memory)
@@ -132,11 +132,13 @@ public:
    * Construct a string long enough to hold the specified # of chars
    * Contents will be initialized to 0
    * @param lengths: the number of chars to store
+   * @param buffer: if specified, use an externally allocated buffer (to avoid memory calls)
 
    * Revision history
-   - SLKP 20170517 reviewed while porting from v3 branch
+      - SLKP 20170517 reviewed while porting from v3 branch
+      - SLKP 2020921 added the option to use external buffers
    */
-  _String(const unsigned long sL);
+  _String(const unsigned long sL, char *buffer = nil);
 
   /**
    * Construct a string representation of a hyFloat(double) to string,
@@ -359,7 +361,7 @@ public:
    *  Revision history
    - SLKP 20170517 reviewed while porting from v3 branch
    */
-  virtual const char get_char(long index) const {
+  virtual char get_char(long index) const {
     if (index >= 0L && index < s_length) {
       return s_data[index];
     }
@@ -376,7 +378,7 @@ public:
    *  Revision history
    - SLKP 20170616 initial implementation
    */
-  inline const char char_at(unsigned long idx) const { return s_data[idx]; }
+  inline char char_at(unsigned long idx) const { return s_data[idx]; }
 
   /** The sole purpose of this function is to allow warning-free compilation of
    calls like array [string.getUChar (i)], otherwise you'd get warnings about
@@ -385,7 +387,7 @@ public:
    *  Revision history
    - SLKP 20170517 reviewed while porting from v3 branch
    */
-  inline const unsigned char get_uchar(long i) const {
+  inline unsigned char get_uchar(long i) const {
     return (unsigned char)s_data[i];
   }
 
@@ -672,7 +674,7 @@ public:
       [CHANGE-NOTE SLKP 20170519 remove the bool argument for memory handling]
    */
 
-  void Trim(long, long);
+  virtual void Trim(long, long);
 
   /**
    * Converts string to a particular case
@@ -686,6 +688,7 @@ public:
       ]
    */
   const _String ChangeCase(hy_string_case conversion_type) const;
+  void   ChangeCaseInPlace(hy_string_case conversion_type);
 
   /**
    * Returns a list from a string split by a substr
@@ -1211,6 +1214,19 @@ public:
    */
   bool StripQuotes(char open_char = '"', char close_char = '"');
 
+    /**
+     * Strips quotes from around the string if present (in place) for multiple delimiters at once
+     * \n\n \b Example: \code _String("\"hyphy\"").StripQuotes("\"'","\"'")\endcode
+     * @param open_char : the opening quote chars (paired with close_char)
+     * @param close_char : the closing quote char (paired with open char)
+     * @return : true if the string was enquoted and the quotes had been stripped
+
+     *  Revision history
+        - SLKP 20200508  initial
+
+     */
+  bool StripQuotes(char const *, char const *);
+
   /**
    * Checks if String is valid ident
    * \n A valid ident is any alphanumeric or '_'
@@ -1304,6 +1320,23 @@ public:
         }
     }
 
+/** a by-character matching iterator
+     
+     
+     @param  cb : a void (char c, unsigned long index) callback argument
+     @param  start_at : start the iteration at this position in the string
+
+         - SLKP 20171008   introduced this function
+
+     */
+
+      template <typename CALLBACK> long Any (CALLBACK cb, unsigned long start_at = 0) const {
+          for (unsigned long i = start_at; i<s_length; i++) {
+              if (cb ( s_data[i], i )) return i;
+          }
+          return kNotFound;
+      }
+
   /**
   * Compute Adler-32 CRC for a string
   * \n\n \b Example: \code _String result = new _String ("Wikipedia"); \endcode
@@ -1453,6 +1486,19 @@ public:
   _SimpleList const RegExpAllMatches(_String const &pattern,
                                      bool case_sensitive,
                                      bool handle_errors) const;
+    /** given coordinates start and end, converts then to valid string indices
+     if called on an empty string, returns 0 and does not change start and end
+     if start < 0 it is reset to 0
+     if end < 0 or >= string length it is reset to (string length) - 1
+
+     @param start: start of the range (0-based)
+     @param end  : end of the range
+     @return     : the length of the range
+
+     * Revision history
+     - SLKP 20170517 porting from v3 branch
+     */
+    long NormalizeRange(long &start, long &end) const;
 
 
 private:
@@ -1522,19 +1568,6 @@ private:
   inline void AllocateAndCopyString(const char *source_string,
                                     unsigned long length);
 
-  /** given coordinates start and end, converts then to valid string indices
-   if called on an empty string, returns 0 and does not change start and end
-   if start < 0 it is reset to 0
-   if end < 0 or >= string length it is reset to (string length) - 1
-
-   @param start: start of the range (0-based)
-   @param end  : end of the range
-   @return     : the length of the range
-
-   * Revision history
-   - SLKP 20170517 porting from v3 branch
-   */
-  long NormalizeRange(long &start, long &end) const;
 
   /** Factored out core of RegExpMatch and RegExpAllMatches
    * Revision history
@@ -1561,54 +1594,4 @@ void ObjectToConsole(BaseRef, void *extra = nil);
 
 _String *StringFromConsole(void);
 
-/** DEPRECATED
- - virtual     void    DuplicateErasing (BaseRef);
- SLKP 20170517 ::Duplicate now clears *this always
- */
-
-/** REMOVED or MOVED
- - virtual     void    DuplicateErasing (BaseRef);
-        SLKP 20170517 ::Duplicate now clears *this always
- - void    CopyDynamicString (_String* s, bool = true);
-    SLKP 20170517 the same can be accomplished by 'x = s' and constructor
- elision
- - bool    iEqual
-    SLKP 20170517 replace with a more general CompareIgnoringCase
- - bool ContainsSubstring (_String&);
-    SLKP 20170612: Never used in the code
- - void    buildKmpTable(_String s);
-    SLKP 20170612: never used
- - long    FindKMP
-    SLKP 20170612: never used
- -  bool iEqual   (_String*);
-    SLKP 20170612: never used
- -  bool contains ({_String, char})
-    SLKP 20170616: never used
- -  bool startswith (_String const&) const;
-    SLKP 20170616: replace with calls to BeginsWith
- -  void SetLength (unsigned long nl)
-    SLKP 20170616: removed because the calling class (CString) has been removed
- -   void    ProcessParameter (void)
-    SLKP 201706016: removed, because the underlying logic has been deprecated
-        (e.g. Tree T = PROMPT_FOR_STRING)
- -  bool IsValidRefIdentifier
-    SLKP 20170616: never used
- -  const _String ShortenVarID     (_String const &) const;
-    SLKP 20170616: never used
- -  _String const PathComposition (_String const) const;
-    SLKP 20170616: never used
- -  _String const PathSubtraction (_String const) const;
-    SLKP 20170616: never used
- -  Sort()
-    SLKP 20170616: never used
- -  ProcessTreeBranchLength ()
-    SLKP 20170616: moved to CalcNode as static
- -    ProcessFileName (bool isWrite = false, bool acceptStringVars = false,
- hyPointer = nil, bool assume_platform_specific = false, _ExecutionList * caller
- = nil); SLKP 20170616: moved to hy_global
- -  SLKP 20170706: removed FindEndOfIdent while rewriting the handler for
- ReplicateConstraint
-
- */
-
 #endif
