@@ -69,15 +69,15 @@ void    PadLine                     (FileState& fState, _DataSet& result);
 void    ISelector                   (FileState& fState, _StringBuffer& CurrentLine, _DataSet& result);
 bool    SkipLine                    (_StringBuffer& theLine, FileState* fS);
 void    TrimPhylipLine              (_StringBuffer& CurrentLine, _DataSet& ds);
-bool    ProcessNexusData            (FileState&, long,  FILE*, _StringBuffer&, _DataSet&);
-void    ProcessNexusHYPHY           (FileState&, long,  FILE*, _StringBuffer&, _DataSet&);
-void    ProcessNexusAssumptions     (FileState&, long,  FILE*, _StringBuffer&, _DataSet&);
-void    ProcessNexusTaxa            (FileState&,long, FILE*, _StringBuffer&, _DataSet&);
-void    ProcessNexusTrees           (FileState&, long, FILE*, _StringBuffer&, _DataSet&);
-bool    FindNextNexusToken          (FileState& fState, FILE* f, _StringBuffer& CurrentLine, long pos);
-bool    SkipUntilNexusBlockEnd      (FileState& fState, FILE* f, _StringBuffer& CurrentLine, long pos);
-bool    ReadNextNexusStatement      (FileState&, FILE* , _StringBuffer&, long, _StringBuffer&, bool, bool = true, bool = true, bool = false, bool = false, bool = false);
-long    ReadNextNexusEquate         (FileState&, FILE* , _StringBuffer&, long, _String&, bool = false, bool = true);
+bool    ProcessNexusData            (FileState&, long,  hyFile*, _StringBuffer&, _DataSet&);
+void    ProcessNexusHYPHY           (FileState&, long,  hyFile*, _StringBuffer&, _DataSet&);
+void    ProcessNexusAssumptions     (FileState&, long,  hyFile*, _StringBuffer&, _DataSet&);
+void    ProcessNexusTaxa            (FileState&,long, hyFile*, _StringBuffer&, _DataSet&);
+void    ProcessNexusTrees           (FileState&, long, hyFile*, _StringBuffer&, _DataSet&);
+bool    FindNextNexusToken          (FileState& fState, hyFile* f, _StringBuffer& CurrentLine, long pos);
+bool    SkipUntilNexusBlockEnd      (FileState& fState, hyFile* f, _StringBuffer& CurrentLine, long pos);
+bool    ReadNextNexusStatement      (FileState&, hyFile* , _StringBuffer&, long, _StringBuffer&, bool, bool = true, bool = true, bool = false, bool = false, bool = false);
+long    ReadNextNexusEquate         (FileState&, hyFile* , _StringBuffer&, long, _String&, bool = false, bool = true);
 void    NexusParseEqualStatement    (_StringBuffer&);
 
 static auto  error_conext = [] (_String const& buffer, long position) -> const _String {return (buffer.Cut (0,position) & " <=? " & buffer.Cut (position+1,kStringEnd)).Enquote();};
@@ -85,7 +85,7 @@ static auto  error_conext = [] (_String const& buffer, long position) -> const _
 
 //_________________________________________________________
 
-bool    FindNextNexusToken (FileState& fState, FILE* f, _StringBuffer& CurrentLine, long pos) {
+bool    FindNextNexusToken (FileState& fState, hyFile* f, _StringBuffer& CurrentLine, long pos) {
 
     pos = CurrentLine.FirstNonSpaceIndex (pos,-1,kStringDirectionForward);
     if (pos==kNotFound) {
@@ -102,7 +102,7 @@ bool    FindNextNexusToken (FileState& fState, FILE* f, _StringBuffer& CurrentLi
 
 //_________________________________________________________
 
-bool    SkipUntilNexusBlockEnd (FileState& fState, FILE* file, _StringBuffer& CurrentLine, long pos) {
+bool    SkipUntilNexusBlockEnd (FileState& fState, hyFile* file, _StringBuffer& CurrentLine, long pos) {
     static const _String endMark ("END");
     pos = CurrentLine.Find (endMark,pos+1,kStringEnd);
     while (pos == kNotFound) {
@@ -143,7 +143,7 @@ void    NexusParseEqualStatement (_StringBuffer& source)
 }
 //_________________________________________________________
 
-bool ReadNextNexusStatement (FileState& fState, FILE* f, _StringBuffer& CurrentLine, long pos, _StringBuffer & blank, bool stopOnSpace, bool stopOnComma, bool stopOnQuote, bool NLonly, bool preserveSpaces, bool preserveQuotes) {
+bool ReadNextNexusStatement (FileState& fState, hyFile* f, _StringBuffer& CurrentLine, long pos, _StringBuffer & blank, bool stopOnSpace, bool stopOnComma, bool stopOnQuote, bool NLonly, bool preserveSpaces, bool preserveQuotes) {
     bool done          = false,
          insideLiteral = false,
          startedReading = false;
@@ -229,7 +229,7 @@ bool ReadNextNexusStatement (FileState& fState, FILE* f, _StringBuffer& CurrentL
 
 //_________________________________________________________
 
-long    ReadNextNexusEquate (FileState& fState, FILE* f, _StringBuffer& CurrentLine, long pos2, _String& blank, bool resetP, bool demandSemicolon) {
+long    ReadNextNexusEquate (FileState& fState, hyFile* f, _StringBuffer& CurrentLine, long pos2, _String& blank, bool resetP, bool demandSemicolon) {
     long pos = blank.Find ('=',pos2,-1), res;
     if (pos>=0) {
         if (pos<blank.length()-1) {
@@ -263,7 +263,7 @@ long    ReadNextNexusEquate (FileState& fState, FILE* f, _StringBuffer& CurrentL
 }
 
 //_________________________________________________________
-void    ProcessNexusTaxa (FileState& fState, long pos, FILE*f, _StringBuffer& CurrentLine, _DataSet& result) {
+void    ProcessNexusTaxa (FileState& fState, long pos, hyFile*f, _StringBuffer& CurrentLine, _DataSet& result) {
     static const _String key1 = "DIMENSIONS", key2 = "NTAX", key3 = "TAXLABELS", keyEnd = "END";
 
     bool    done = false;
@@ -344,7 +344,7 @@ void    ProcessNexusTaxa (FileState& fState, long pos, FILE*f, _StringBuffer& Cu
 
 //_________________________________________________________
 
-void    ProcessNexusAssumptions (FileState& fState, long pos, FILE*f, _StringBuffer& CurrentLine, _DataSet&) {
+void    ProcessNexusAssumptions (FileState& fState, long pos, hyFile*f, _StringBuffer& CurrentLine, _DataSet&) {
     static const _String key1 = "CHARSET", keyEnd = "END";
  
     bool    done = false;
@@ -570,7 +570,7 @@ void    ProcessNexusAssumptions (FileState& fState, long pos, FILE*f, _StringBuf
 
 //_________________________________________________________
 
-void    ProcessNexusTrees (FileState& fState, long pos, FILE*f, _StringBuffer& CurrentLine, _DataSet& result) {
+void    ProcessNexusTrees (FileState& fState, long pos, hyFile*f, _StringBuffer& CurrentLine, _DataSet& result) {
     static _String const key1 = "TRANSLATE", key2 = "TREE", errMsg, keyEnd = "END";
 
     bool    done = false, readResult, good;
@@ -615,7 +615,7 @@ void    ProcessNexusTrees (FileState& fState, long pos, FILE*f, _StringBuffer& C
                 if (readResult) {
                     break;
                 }
-                if  ((f&&feof(f))||(fState.theSource&&(fState.theSource->length()<=fState.pInSrc))) {
+                if  ((f&&f->feof())||(fState.theSource&&(fState.theSource->length()<=fState.pInSrc))) {
                     break;
                 }
                 offset = 0;
@@ -815,7 +815,7 @@ void    ProcessNexusTrees (FileState& fState, long pos, FILE*f, _StringBuffer& C
 
 //_________________________________________________________
 
-void    ProcessNexusHYPHY (FileState& fState, long pos, FILE*file, _StringBuffer& CurrentLine, _DataSet&) {
+void    ProcessNexusHYPHY (FileState& fState, long pos, hyFile*file, _StringBuffer& CurrentLine, _DataSet&) {
     static _String const endMark ("END;");
     _StringBuffer bfBody  (128UL);
 
@@ -863,7 +863,7 @@ void    ProcessNexusHYPHY (FileState& fState, long pos, FILE*file, _StringBuffer
 
 //_________________________________________________________
 
-bool    ProcessNexusData (FileState& fState, long pos, FILE*f, _StringBuffer& CurrentLine, _DataSet& result) {
+bool    ProcessNexusData (FileState& fState, long pos, hyFile*f, _StringBuffer& CurrentLine, _DataSet& result) {
     static const _String key1 ("DIMENSIONS"), key11 ("NTAX"), key12 ("NCHAR"),
             key2 ("FORMAT"),key21 ("DATATYPE"), key22 ("MISSING"), key23 ("GAP"), key24 ("SYMBOLS"),
             key25 ("EQUATE"), key26 ("MATCHCHAR"), key27 ("NOLABELS"), key28 ("INTERLEAVE"), key3 ("MATRIX"), keyEnd ("END");
@@ -1217,7 +1217,7 @@ bool    ProcessNexusData (FileState& fState, long pos, FILE*f, _StringBuffer& Cu
                         break;    // finished reading
                     }
 
-                if  ((f&&feof(f))||(fState.theSource&&(fState.theSource->length()<=fState.pInSrc))) {
+                if  ((f&&f->feof())||(fState.theSource&&(fState.theSource->length()<=fState.pInSrc))) {
                     break;
                 }
             }
@@ -1258,7 +1258,7 @@ bool    ProcessNexusData (FileState& fState, long pos, FILE*f, _StringBuffer& Cu
 
 //_________________________________________________________
 
-void    ReadNexusFile (FileState& fState, FILE*file, _DataSet& result) {
+void    ReadNexusFile (FileState& fState, hyFile*file, _DataSet& result) {
     bool   dataRead = false, lookForEnd = false;
     long   f,g, file_line = fState.currentFileLine;
 
