@@ -79,12 +79,20 @@ _TranslationTable::_TranslationTable(unsigned char baseL) {
 
 //_________________________________________________________
 _TranslationTable::_TranslationTable(_TranslationTable const &t) {
-  tokensAdded = t.tokensAdded;
-  baseLength = t.baseLength;
-  baseSet = t.baseSet;
-  translationsAdded << t.translationsAdded;
-  checkTable = NULL;
+   *this = t;
 }
+                                                 
+//_________________________________________________________
+_TranslationTable const & _TranslationTable::operator = (_TranslationTable const &t) {
+   if (this != &t) {
+       tokensAdded = t.tokensAdded;
+       baseLength = t.baseLength;
+       baseSet = t.baseSet;
+       translationsAdded << t.translationsAdded;
+       checkTable = NULL;
+    }
+    return *this;
+ }
 
 //_________________________________________________________
 _TranslationTable::_TranslationTable(_String &alphabet) {
@@ -213,7 +221,7 @@ const _String _TranslationTable::ExpandToken(char token) const {
   _String const *base_set = &GetAlphabetString();
   _StringBuffer expansion(base_set->length());
 
-  for (unsigned long tc = 0; tc < resolution_count; tc++) {
+  for (long tc = 0; tc < resolution_count; tc++) {
     expansion << base_set->char_at(buf[tc]);
   }
 
@@ -900,6 +908,35 @@ _TranslationTable::ConvertCodeToLetters(long code, unsigned char base) const {
 
 //_________________________________________________________
 
+bool _TranslationTable::operator == (const _TranslationTable& rhs) const {
+    
+    if (baseSet.length() == rhs.baseSet.length()) {
+        if (baseSet.empty()) { // standard alphabet
+            if (baseLength != rhs.baseLength) {
+                return false;
+            }
+        } else if (baseSet != rhs.baseSet) {
+            return false;
+        }
+        
+        if (tokensAdded.length() == rhs.tokensAdded.length()) {
+            
+            for (unsigned i = 0; i < tokensAdded.length(); i++) {
+                if (ExpandToken (tokensAdded.get_char(i)) != rhs.ExpandToken (tokensAdded.get_char(i))) {
+                    return false;
+                }
+            }
+            
+            return true;
+        }
+        
+    }
+    return false;
+
+}
+
+//_________________________________________________________
+
 _TranslationTable *
 _TranslationTable::MergeTables(_TranslationTable const *table2) const
 // merge the translation tables if they are compatible, return the result,
@@ -919,7 +956,7 @@ _TranslationTable::MergeTables(_TranslationTable const *table2) const
       for (long i = 0; i < table2->tokensAdded.length(); i++) {
         long f = tokensAdded.Find(table2->tokensAdded[i]);
         if (f == -1) {
-          result->tokensAdded && table2->tokensAdded[i];
+          result->tokensAdded = result->tokensAdded & table2->tokensAdded[i];
           // SLKP 20071002 added the next line;
           // was not adding the translation for the new token
           result->translationsAdded << table2->translationsAdded(i);
